@@ -334,7 +334,7 @@ class ProvPopTableResultsWrapper():
 
     def plot_pop(
         self, 
-        sex: None,
+        sex = None,
         of: str = 'both',
         age_range: Optional[List[int]] = None,
         alpha: float = .5
