@@ -849,5 +849,36 @@ def run5():
 def run6():
     poptbl_regions = run5()
     poptbl_1001 = poptbl_regions[1001]
-    poptbl_1001_fixed = poptbl_1001.fix_issues(return_all_mods = True)
-    return poptbl_1001_fixed
+    poptbl_1010 = poptbl_regions[1010]
+    estime2.options.method = '1dist'
+    poptbl_1001_fixed_onedist =\
+        poptbl_1001.fix_issues(return_all_mods = True)
+    poptbl_1010_fixed_onedist =\
+        poptbl_1010.fix_issues(return_all_mods = True)
+    
+    print(poptbl_1001_fixed_onedist.summary())
+    print('')
+    print(poptbl_1010_fixed_onedist.summary())
+    print('')
+
+    estime2.options.method = 'filler'
+    poptbl_1001_fixed_filler =\
+        poptbl_1001.fix_issues(return_all_mods = True)
+    poptbl_1010_fixed_filler =\
+        poptbl_1010.fix_issues(return_all_mods = True)
+    
+    print(poptbl_1001_fixed_filler.summary())
+    print('')
+    print(poptbl_1010_fixed_filler.summary())
+    print('')
+
+    estime2.options.method = 'prop'
+    poptbl_1001_fixed_prop =\
+        poptbl_1001.fix_issues(return_all_mods = True)
+    poptbl_1010_fixed_prop =\
+        poptbl_1010.fix_issues(return_all_mods = True)
+
+    print(poptbl_1001_fixed_prop.summary())
+    print('')
+    print(poptbl_1010_fixed_prop.summary())
+    print('')
